@@ -20,7 +20,7 @@ S = Settings({
     'default_permission': 'see',
     'require_csrf': True,
     'target_url': '/',
-    'redis.users.prefix': 'user.',
+    'redis.user_tickets.key': 'user.{user_id}.tickets',
 })
 L = get_log(__name__)
 
